@@ -1242,8 +1242,6 @@
             ? navigator.userAgentData.platform.toLowerCase()
             : navigator.platform.toLowerCase()
         : "some platform";
-    const isChromium =
-        userAgent.includes("chrome") || userAgent.includes("chromium");
     const isThunderbird = userAgent.includes("thunderbird");
     const isFirefox =
         userAgent.includes("firefox") ||
@@ -1253,7 +1251,6 @@
     userAgent.includes("yabrowser");
     userAgent.includes("opr") || userAgent.includes("opera");
     userAgent.includes("edg");
-    userAgent.includes("safari") && !isChromium;
     platform.startsWith("win");
     platform.startsWith("mac");
     isNavigatorDefined && navigator.userAgentData
